<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="指标名称" prop="categoryName">
        <el-input v-model="queryParams.categoryName" placeholder="请输入指标类别名称" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="所属组别" prop="groupID">
        <el-input v-model="queryParams.groupID" placeholder="请输入组别" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="指标值" prop="targetValue">
        <el-input v-model="queryParams.targetValue" placeholder="请输入指标值" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="适用语言" prop="language">
        <el-input v-model="queryParams.language" placeholder="请选择语言" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="适用院区" prop="orgid">
        <el-input v-model="queryParams.orgid" placeholder="请输入 医院院区 " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['smartor:ivrtarget:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['smartor:ivrtarget:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['smartor:ivrtarget:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['smartor:ivrtarget:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="ivrtargetList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="指标类别" align="center" prop="targetType" />
      <el-table-column label="指标名称" align="center" prop="categoryName" />
      <el-table-column label="指标值" align="center" prop="targetValue" />
      <el-table-column label="适用语言" align="center" prop="language" />
      <el-table-column label="版本号" align="center" prop="version" />
      <el-table-column label="启用标致" align="center" prop="isEnable" />
      <el-table-column label="组别" align="center" prop="groupID" />
      <el-table-column label="异常标识" align="center" prop="isAbnormal" />
      <el-table-column label="适用院区 " align="center" prop="orgid" />
      <el-table-column label="说明" align="center" prop="Remark" />
      <el-table-column label="创建时间" align="center" prop="addTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.addTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:ivrtarget:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:ivrtarget:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改指标库对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="1000px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row>
          <el-col :span="12"><el-form-item label="指标组别" prop="groupID">
              <el-input v-model="form.groupID" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="版 本 号" prop="version">
              <el-input v-model="form.version" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row> <el-row>
          <el-col :span="12"><el-form-item label="指标名称" prop="categoryName">
              <el-input v-model="form.categoryName" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="指标值" prop="targetValue">
              <el-input v-model="form.targetValue" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"><el-form-item label="适用语言" prop="language">
              <el-input v-model="form.language" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"> <el-form-item label="启用状态" prop="isEnable">
              <el-input v-model="form.isEnable" placeholder="请输入${comment}" />
            </el-form-item></el-col><el-col :span="12">
            <el-form-item label=" 删除标记 " prop="delFlag">
              <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"><el-form-item label="预警阀值上限" prop="WarnUp">
              <el-input v-model="form.WarnUp" placeholder="请输入预警阀值上限" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="预警阀值下限" prop="WarnDown">
              <el-input v-model="form.WarnDown" placeholder="请输入预警阀值下限" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"><el-form-item label="异常标识" prop="isAbnormal">
              <el-input v-model="form.isAbnormal" placeholder="请输入是否异常标识" />
            </el-form-item></el-col>
        </el-row><el-row>
          <el-col :span="24"><el-form-item label=" 适用院区 " prop="orgid">
              <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
            </el-form-item></el-col>
        </el-row><el-row>
          <el-col :span="24"> <el-form-item label="说    明" prop="Remark">
              <el-input v-model="form.Remark" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row><el-row>
          <el-col :span="24"> <el-form-item label="匹配规则" prop="targetRegex">
              <el-input v-model="form.targetRegex" type="textarea" placeholder="请输入内容" />
            </el-form-item></el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listIvrtarget, getIvrtarget, delIvrtarget, addIvrtarget, updateIvrtarget } from "@/api/smartor/ivrtarget";

export default {
  name: "Ivrtarget",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 指标库表格数据
      ivrtargetList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        targetType: null,
        categoryName: null,
        targetValue: null,
        targetRegex: null,
        Remark: null,
        language: null,
        version: null,
        isEnable: null,
        isDel: null,
        addUserID: null,
        addTime: null,
        modifyUserID: null,
        modifyTime: null,
        groupID: null,
        isAbnormal: null,
        WarnUp: null,
        WarnDown: null,
        isupload: null,
        uploadTime: null,
        orgid: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        targetType: [
          { required: true, message: "$comment不能为空", trigger: "change" }
        ],
        categoryName: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        language: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        version: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isEnable: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isDel: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isAbnormal: [
          { required: true, message: "是否异常标识不能为空", trigger: "blur" }
        ],
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询指标库列表 */
    getList() {
      this.loading = true;
      listIvrtarget(this.queryParams).then(response => {
        this.ivrtargetList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        targetID: null,
        targetType: null,
        categoryName: null,
        targetValue: null,
        targetRegex: null,
        Remark: null,
        language: null,
        version: null,
        isEnable: null,
        isDel: null,
        addUserID: null,
        addTime: null,
        modifyUserID: null,
        modifyTime: null,
        groupID: null,
        isAbnormal: null,
        WarnUp: null,
        WarnDown: null,
        delFlag: null,
        updateBy: null,
        updateTime: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        orgid: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.targetID)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加指标库";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const targetID = row.targetID || this.ids
      getIvrtarget(targetID).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改指标库";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.targetID != null) {
            updateIvrtarget(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addIvrtarget(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const targetIDs = row.targetID || this.ids;
      this.$modal.confirm('是否确认删除指标库编号为"' + targetIDs + '"的数据项？').then(function () {
        return delIvrtarget(targetIDs);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/ivrtarget/export', {
        ...this.queryParams
      }, `ivrtarget_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
